@@ -4,8 +4,8 @@ package chezmoi
 import (
 	"bufio"
 	"bytes"
-	"crypto/md5"  //nolint:gosec
-	"crypto/sha1" //nolint:gosec
+	"crypto/md5"
+	"crypto/sha1"
 	"crypto/sha256"
 	"crypto/sha512"
 	"fmt"
@@ -16,6 +16,7 @@ import (
 	"runtime"
 	"strconv"
 	"strings"
+	"sync"
 
 	"github.com/spf13/cobra"
 	vfs "github.com/twpayne/go-vfs/v5"
@@ -186,12 +187,6 @@ func ParseBool(str string) (bool, error) {
 	}
 }
 
-// SHA256Sum returns the SHA256 sum of data.
-func SHA256Sum(data []byte) []byte {
-	sha256SumArr := sha256.Sum256(data)
-	return sha256SumArr[:]
-}
-
 // SuspiciousSourceDirEntry returns true if base is a suspicious dir entry.
 func SuspiciousSourceDirEntry(base string, fileInfo fs.FileInfo, encryptedSuffixes []string) bool {
 	switch fileInfo.Mode().Type() {
@@ -237,6 +232,14 @@ func UniqueAbbreviations(values []string) map[string]string {
 	return uniqueAbbreviations
 }
 
+// eagerNoErr returns a function that returns an eagerly-evaluated value and no
+// error.
+func eagerNoErr[T any](value T) func() (T, error) {
+	return func() (T, error) {
+		return value, nil
+	}
+}
+
 // etcHostnameFQDNHostname returns the FQDN hostname from parsing /etc/hostname.
 func etcHostnameFQDNHostname(fileSystem vfs.FS) (string, error) {
 	contents, err := fileSystem.ReadFile("/etc/hostname")
@@ -333,10 +336,21 @@ func isReadOnly(fileInfo fs.FileInfo) bool {
 
 // md5Sum returns the MD5 sum of data.
 func md5Sum(data []byte) []byte {
-	md5SumArr := md5.Sum(data) //nolint:gosec
+	md5SumArr := md5.Sum(data)
 	return md5SumArr[:]
 }
 
+// lazySHA256 returns a function that returns a SHA256 computed lazily.
+func lazySHA256(contentsFunc func() ([]byte, error)) func() ([32]byte, error) {
+	return sync.OnceValues(func() ([32]byte, error) {
+		contents, err := contentsFunc()
+		if err != nil {
+			return [32]byte{}, err
+		}
+		return sha256.Sum256(contents), nil
+	})
+}
+
 // modeTypeName returns a string representation of mode.
 func modeTypeName(mode fs.FileMode) string {
 	if name, ok := FileModeTypeNames[mode.Type()]; ok {
@@ -352,7 +366,7 @@ func ripemd160Sum(data []byte) []byte {
 
 // sha1Sum returns the SHA1 sum of data.
 func sha1Sum(data []byte) []byte {
-	sha1SumArr := sha1.Sum(data) //nolint:gosec
+	sha1SumArr := sha1.Sum(data)
 	return sha1SumArr[:]
 }
 
