@@ -20,16 +20,11 @@ var rbwMinVersion = semver.Version{Major: 1, Minor: 7, Patch: 0}
 
 func (c *Config) rbwFieldsTemplateFunc(name string, extraArgs ...string) map[string]any {
 	args := append([]string{"get", "--raw", name}, extraArgs...)
-	output, err := c.rbwOutput(args)
-	if err != nil {
-		panic(err)
-	}
+	output := mustValue(c.rbwOutput(args))
 	var data struct {
 		Fields []map[string]any `json:"fields"`
 	}
-	if err := json.Unmarshal(output, &data); err != nil {
-		panic(newParseCmdOutputError(c.RBW.Command, args, output, err))
-	}
+	must(json.Unmarshal(output, &data))
 	result := make(map[string]any)
 	for _, field := range data.Fields {
 		if name, ok := field["name"].(string); ok {
@@ -41,14 +36,9 @@ func (c *Config) rbwFieldsTemplateFunc(name string, extraArgs ...string) map[str
 
 func (c *Config) rbwTemplateFunc(name string, extraArgs ...string) map[string]any {
 	args := append([]string{"get", "--raw", name}, extraArgs...)
-	output, err := c.rbwOutput(args)
-	if err != nil {
-		panic(err)
-	}
+	output := mustValue(c.rbwOutput(args))
 	var data map[string]any
-	if err := json.Unmarshal(output, &data); err != nil {
-		panic(newParseCmdOutputError(c.RBW.Command, args, output, err))
-	}
+	must(json.Unmarshal(output, &data))
 	return data
 }
 
